@@ -1,41 +1,58 @@
 #' Spell checking
 #'
 #' @param filename Path to a LaTeX file to check.
+#' @param tex_root The root path of the filename. Provide this if you are checking an \code{\\input}
+#' file that has a different root directory to its parent.
 #' @param pre_release Should the document be assumed to be final?
-#' Setting to \code{FALSE} permits the use of \code{ignore_spelling_in} and permits \code{add_to_dictionary} to be
+#' Setting to \code{FALSE} permits the use of \code{ignore_spelling_in} and permits 
+#' \code{add_to_dictionary} to be
 #' present outside the document preamble.
 #' @param ignore.lines Integer vector of lines to ignore (due to possibly spurious errors).
-#' @param known.correct Character vector of patterns known to be correct (which will never be raised by this function).
-#' @param known.correct.fixed Character vector of words known to be correct (which will never be raised by this function).
+#' @param known.correct Character vector of patterns known to be correct (which will never be raised
+#'  by this function).
+#' @param known.correct.fixed Character vector of words known to be correct (which will never be 
+#' raised by this function).
 #' @param known.wrong Character vector of patterns known to be wrong.
 #' @param ignore_spelling_in Command whose first mandatory argument will be ignored.
 #' @param ignore_spelling_in_nth Named list of arguments to ignore; names are the commands to be ignored, values are the \code{n}th argument to be ignored.
-#' @param bib_files Bibliography files (containing possible clues to misspellings). If supplied, and this function would otherwise throw an error, the \code{.bib} files are read and any author names that match the misspelled words are added to the dictionary.
-#' @param check_etcs If \code{TRUE}, stop if any variations of \code{etc}, \code{ie}, and \code{eg} are present. (If they are typed literally, they may be formatted inconsistently. Using a macro ensures they appear consistently.)
+#' @param bib_files Bibliography files (containing possible clues to misspellings). If supplied, and
+#'  this function would otherwise throw an error, the \code{.bib} files are read and any author 
+#'  names that match the misspelled words are added to the dictionary.
+#' @param check_etcs If \code{TRUE}, stop if any variations of \code{etc}, \code{ie}, and \code{eg}
+#'  are present. (If they are typed literally, they may be formatted inconsistently. Using a macro
+#'  ensures they appear consistently.)
 #' @param dict_lang Passed to \code{hunspell::dictionary}.
 #' @param rstudio Use the RStudio API?
-#' @param .report_error A function to provide context to any errors. If missing, defaults to \code{\link{report2console}}.
-#' @return Called primarily for its side-effect. If the spell check fails, the line at which the first error was detected, with an error message. If the check succeeds, \code{NULL} invisibly.
+#' @param .report_error A function to provide context to any errors. If missing, defaults to 
+#' \code{\link{report2console}}.
+#' @return Called primarily for its side-effect. If the spell check fails, the line at which the 
+#' first error was detected, with an error message. If the check succeeds, \code{NULL} invisibly.
 #' 
 #' @details Extends and enhances \code{hunspell}:
 #' 
 #'  \itemize{
 #' \item{You can add directives 
-#' in the document itself. To add a word \code{foobaz} to the dictionary (so its presence does not throw an error), write
-#' \code{\% add_to_dictionary: foobaz} on a single line. The advantage of this method is that you can collaborate
-#' on the document without having to keep track of which spelling errors are genuine.}
+#' in the document itself. To add a word \code{foobaz} to the dictionary (so its presence does not
+#'  throw an error), write \code{\% add_to_dictionary: foobaz} on a single line. The advantage of 
+#'  this method is that you can collaborate on the document without having to keep track of which
+#'  spelling errors are genuine.}
 #' \item{The 
 #' directive \code{\% ignore_spelling_in: mycmd} which will ignore the spelling of words within the first argument
 #' of \code{\\mycmd}.}
-#' \item{\code{ignore_spelling_in_file: <file.tex>} will skip the check of \code{<file.tex>} if it is \code{input} or \code{include} in \code{filename}, as well as any files within it. Should appear as it is within \code{input} but with the file extension}
+#' \item{\code{ignore_spelling_in_file: <file.tex>} will skip the check of \code{<file.tex>} if it 
+#' is \code{input} or \code{include} in \code{filename}, as well as any files within it. Should 
+#' appear as it is within \code{input} but with the file extension}
 #' 
 #' \item{Only the root document need be supplied; 
 #' any files that are fed via \code{\\input} or \code{\\include} are checked (recursively).}
 #' 
 #' \item{A historical advantages was that the contents of certain commands were not checked, the spelling of which need not be checked 
-#' as they are not printed, \code{viz.} citation and cross-reference commands, and certain optional arguments. Most of these
-#' are now parsed correctly by \code{\link[hunspell]{hunspell}}, though some still need to be supplied (including, naturally, user-supplied macros).}
-#' \item{Abbreviations and initialisms which are validly introduced will not throw errors. See \code{\link{extract_valid_abbrevations}}.}
+#' as they are not printed, \code{viz.} citation and cross-reference commands, and certain optional
+#' arguments. Most of these
+#' are now parsed correctly by \code{\link[hunspell]{hunspell}}, though some still need to be 
+#' supplied (including, naturally, user-supplied macros).}
+#' \item{Abbreviations and initialisms which are validly introduced will not throw errors. See
+#' \code{\link{extract_valid_abbrevations}}.}
 #' \item{Words preceded by '[sic]' will not throw errors.}
 #' }
 #' 
@@ -49,7 +66,7 @@
 #' explicitly, or using \code{citeauthor} and friends. 
 #' 
 #' This function is forked from \url{https://github.com/hughparsonage/grattanReporter} to parse reports of the Grattan Institute, Melbourne for errors. See
-#' \url{https://github.com/HughParsonage/grattex/blob/master/doc/grattexDocumentation.pdf} for the full spec.
+#' \url{https://github.com/grattan/grattex/blob/master/doc/grattexDocumentation.pdf} for the full spec.
 #' Some checks that package performs have been omitted in this package.
 #' 
 #' @examples 
@@ -66,6 +83,7 @@
 #' 
 
 check_spelling <- function(filename,
+                           tex_root = dirname(filename),
                            pre_release = TRUE,
                            ignore.lines = NULL,
                            known.correct = NULL,
@@ -79,7 +97,7 @@ check_spelling <- function(filename,
                            rstudio = FALSE,
                            
                            .report_error){
-  if (missing(.report_error)){
+  if (missing(.report_error)) {
     if (rstudio) {
       if (!interactive()) {
         stop("Argument 'rstudio' is only valid in interactive sessions.")
@@ -94,7 +112,8 @@ check_spelling <- function(filename,
     }
   }
 
-  file_path <- dirname(filename)
+  file_path <- tex_root
+
   orig <- lines <- read_lines(filename)
   
   # Quick way to identify end document if it exists, avoids issues 
@@ -108,6 +127,9 @@ check_spelling <- function(filename,
   # Smart quotes
   lines <- gsub(parse(text = paste0("'", "\u2019", "'")), "'", lines, fixed = TRUE)
   lines <- gsub(parse(text = paste0("'", "\u2018", "'")), "'", lines, fixed = TRUE)
+  
+  # Trailing apostrophes tend to cause false positives
+  lines <- gsub("'s\\b", "", lines, perl = TRUE)
 
   if (!is.null(ignore.lines)){
     lines[ignore.lines] <- ""
@@ -237,21 +259,29 @@ check_spelling <- function(filename,
     }
 
   if (length(inputs)) {
+    
     # Recursively check
     cat_("Check subfiles:\n")
     for (input in inputs) {
+
+      # If nested, remove duplicated folder in path. See isse #75
+      # .file_path <- get_input_file_path(.path = file_path,
+      #                                   .input = input)
+
       cat_(input, "\n")
-      check_spelling(filename = file.path(file_path,
-                                          paste0(sub("\\.tex?", "", input, perl = TRUE),
-                                                 ".tex")),
+
+      check_spelling(filename = file.path(tex_root, input),
+                     tex_root = tex_root,
                      pre_release = pre_release,
                      known.correct = known.correct,
                      known.wrong = known.wrong, 
                      ignore_spelling_in = c(commands_to_ignore, ignore_spelling_in),
+                     ignore_spelling_in_nth = ignore_spelling_in_nth,
                      dict_lang = dict_lang,
                      rstudio = rstudio)
     }
   }
+
   
   if (any(grepl("\\verb", lines, fixed = TRUE))) {
     lines <- gsub("\\\\verb(.)(.+?)\\1", "\\verb", lines)
@@ -542,7 +572,7 @@ check_spelling <- function(filename,
           .report_error(line_no = line_w_misspell,
                         column = chars_b4_badword + nchar_of_badword + 1L,
                         context = context,
-                        error_message = paste0("Spellcheck failed: '", bad_word, "'"),
+                        error_message = paste0("Spellcheck failed: '", bad_word, "' in ", filename),
                         extra_cat_post = c("\n",
                                            rep(" ", chars_b4_badword + 5 + nchar(line_w_misspell)),
                                            rep("^", nchar_of_badword),
@@ -573,3 +603,22 @@ check_spelling <- function(filename,
 
   return(invisible(NULL))
 }
+
+
+
+
+
+get_input_file_path <- function(.path, .input) {
+  
+  last_of_file_path <- gsub(".*?([a-zA-Z0-9\\-]*?$)", "\\1", .path, perl = TRUE)
+  first_of_input <- gsub("^([a-zA-Z0-9\\-]*).*", "\\1", .input, perl = TRUE)
+  
+  if (last_of_file_path == first_of_input) .input <- gsub(paste0(first_of_input, "\\/"), "", .input)
+  if (last_of_file_path == first_of_input) .input <- gsub(paste0(first_of_input, "\\\\"), "", .input)
+  
+  
+  .file_path <- file.path(.path,
+                          paste0(sub("\\.tex?", "", .input, perl = TRUE),
+                                 ".tex"))
+  return(.file_path)
+}
