@@ -4,3 +4,7 @@ test_that("Dollar signs are not allowed.", {
   expect_error(check_escapes("./check-escapes/fail.tex"))
   expect_error(check_escapes("./check-escapes/fail-2.tex"))
 })
+
+test_that("Dollar signs in comments ok", {
+  expect_null(check_escapes("./check-escapes/ok-behind-percent.tex"))
+})
