@@ -27,6 +27,19 @@ test_that("GRP_ID identifies group", {
   expect_equal(x_parsed[4][["GROUP_ID1"]], x_parsed[8][["GROUP_ID1"]])
 })
 
+test_that("Verify % is not parsed", {
+  expect_identical(parse_tex(c("A {", "f ", "Z}")),
+                   parse_tex(c("A {", "f %}", "Z}%[]")))
+})
+
+test_that("Parse tiny documents", {
+  library(data.table)
+  expect_identical(parse_tex(character(0L)), data.table())
+  expect_identical(parse_tex(c("", "A{B}"))[["GROUP_ID1"]], 
+                   c(NA_integer_, 1L, 1L, 1L))
+  expect_equal(range(parse_tex(c("", ""))[["line_no"]]), 1:2)
+                   
+})
 
 
 
